@@ -30,17 +30,19 @@
 package SNMP::Info::Aggregate;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::Aggregate::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::Aggregate::EXPORT_OK = qw/agg_ports_ifstack/;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.23';
+$VERSION = '3.76';
 
-%MIBS = (); # IF-MIB
+# Load MIB for leafs referenced within class
+%MIBS = ('IF-MIB' => 'ifIndex',);
 
 %GLOBALS = ();
 
@@ -61,7 +63,7 @@ sub agg_ports_ifstack {
   foreach my $idx ( keys %$ifStack ) {
       my ( $higher, $lower ) = split /\./, $idx;
       next if ( $higher == 0 or $lower == 0 );
-      if ( $ifType->{ $higher } eq 'ieee8023adLag' ) {
+      if ( $ifType->{ $higher } eq 'ieee8023adLag'  or $ifType->{ $higher } eq 'propMultiplexor') {
           $ret->{ $lower } = $higher;
       }
   }
@@ -83,14 +85,14 @@ SNMP::Info Developers
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $info = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $info->class();
