@@ -1,5 +1,4 @@
 # SNMP::Info::Bridge
-# $Id$
 #
 # Changes since Version 0.7 Copyright (c) 2004 Max Baker
 # All rights reserved.
@@ -34,19 +33,21 @@
 package SNMP::Info::Bridge;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::Bridge::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::Bridge::EXPORT_OK = qw//;
 
-use vars qw/$VERSION $DEBUG %MIBS %FUNCS %GLOBALS %MUNGE $INIT/;
+our ($VERSION, $DEBUG, %MIBS, %FUNCS, %GLOBALS, %MUNGE, $INIT);
 
-$VERSION = '3.23';
+$VERSION = '3.76';
 
 %MIBS = (
     'BRIDGE-MIB'   => 'dot1dBaseBridgeAddress',
     'Q-BRIDGE-MIB' => 'dot1qPvid',
+    'RSTP-MIB'     => 'dot1dStpPortOperEdgePort',
 );
 
 %GLOBALS = (
@@ -104,6 +105,10 @@ $VERSION = '3.23';
     'stp_p_bridge'   => 'dot1dStpPortDesignatedBridge',
     'stp_p_port'     => 'dot1dStpPortDesignatedPort',
 
+    # Rapid Spanning Tree Protocol Table : dot1dStpExtPortEntry
+    'is_edgeport_admin' => 'dot1dStpPortAdminEdgePort',
+    'is_edgeport_oper'  => 'dot1dStpPortOperEdgePort',
+
     # Q-BRIDGE-MIB : dot1qPortVlanTable
     'qb_i_vlan'        => 'dot1qPvid',
     'qb_i_vlan_type'   => 'dot1qPortAcceptableFrameTypes',
@@ -184,7 +189,7 @@ sub qb_fw_vlan {
     foreach my $idx ( keys %$qb_fw_port ) {
         my ( $fdb_id, $mac ) = _qb_fdbtable_index($idx);
         # Many devices do not populate the dot1qVlanCurrentTable, so default
-        # to FDB ID = VID, but if we have a mapping use it.  
+        # to FDB ID = VID, but if we have a mapping use it.
         my $vlan = $fdb_id;
         # defined as test since some devices have a vlan 0
         if (defined $qb_fdb_ids->{$fdb_id}) {
@@ -224,21 +229,23 @@ sub qb_fdb_index {
 
     # Strip the TimeFilter
     my $vl_fdb_index = {};
-    for my $orig (keys(%$qb_fdb_ids)) {
-        (my $new = $orig) =~ s/^\d+\.//;
-        $vl_fdb_index->{$new} = $qb_fdb_ids->{$orig};
+    for my $fdb_entry (keys(%$qb_fdb_ids)) {
+        (my $vlan = $fdb_entry) =~ s/^\d+\.//;
+        $vl_fdb_index->{$qb_fdb_ids->{$fdb_entry}} = $vlan;
     }
 
     return $vl_fdb_index;
 }
 
-# Most devices now support Q-BRIDGE-MIB, fall back to 
+# Most devices now support Q-BRIDGE-MIB, fall back to
 # BRIDGE-MIB for those that don't.
 sub fw_mac {
     my $bridge = shift;
 
-    my $qb = $bridge->qb_fw_mac();
-    return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    unless ($bridge->can('cisco_comm_indexing') && $bridge->cisco_comm_indexing()){
+        my $qb = $bridge->qb_fw_mac();
+        return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    }
 
     return $bridge->SUPER::fw_mac();
 }
@@ -246,8 +253,10 @@ sub fw_mac {
 sub fw_port {
     my $bridge = shift;
 
-    my $qb = $bridge->qb_fw_port();
-    return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    unless ($bridge->can('cisco_comm_indexing') && $bridge->cisco_comm_indexing()){
+        my $qb = $bridge->qb_fw_port();
+        return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    }
 
     return $bridge->SUPER::fw_port();
 }
@@ -255,9 +264,11 @@ sub fw_port {
 sub fw_status {
     my $bridge = shift;
 
-    my $qb = $bridge->qb_fw_status();
-    return $qb if (ref {} eq ref $qb and scalar keys %$qb);
-    
+    unless ($bridge->can('cisco_comm_indexing') && $bridge->cisco_comm_indexing()){
+        my $qb = $bridge->qb_fw_status();
+        return $qb if (ref {} eq ref $qb and scalar keys %$qb);
+    }
+
     return $bridge->SUPER::fw_status();
 }
 
@@ -291,11 +302,11 @@ sub i_stp_port {
     my %i_stp_port;
 
     foreach my $index ( keys %$stp_p_port ) {
-        my $bridge = $stp_p_port->{$index};
+        my $bport  = $stp_p_port->{$index};
         my $iid    = $bp_index->{$index};
         next unless defined $iid;
-        next unless defined $bridge;
-        $i_stp_port{$iid} = $bridge;
+        next unless defined $bport;
+        $i_stp_port{$iid} = $bport;
     }
     return \%i_stp_port;
 }
@@ -310,11 +321,11 @@ sub i_stp_id {
     my %i_stp_id;
 
     foreach my $index ( keys %$stp_p_id ) {
-        my $bridge = $stp_p_id->{$index};
+        my $bport  = $stp_p_id->{$index};
         my $iid    = $bp_index->{$index};
         next unless defined $iid;
-        next unless defined $bridge;
-        $i_stp_id{$iid} = $bridge;
+        next unless defined $bport;
+        $i_stp_id{$iid} = $bport;
     }
     return \%i_stp_id;
 }
@@ -329,11 +340,11 @@ sub i_stp_bridge {
     my %i_stp_bridge;
 
     foreach my $index ( keys %$stp_p_bridge ) {
-        my $bridge = $stp_p_bridge->{$index};
+        my $bport  = $stp_p_bridge->{$index};
         my $iid    = $bp_index->{$index};
         next unless defined $iid;
-        next unless defined $bridge;
-        $i_stp_bridge{$iid} = $bridge;
+        next unless defined $bport;
+        $i_stp_bridge{$iid} = $bport;
     }
     return \%i_stp_bridge;
 }
@@ -418,7 +429,7 @@ sub _vlan_hoa {
         my $vlan;
 
         # Strip TimeFilter if we're using VlanCurrentTable
-        ( $vlan = $idx ) =~ s/^\d+\.//;
+        ($vlan = $idx) =~ s/^(\d+\.)*//g;
 
         # Convert portlist bit array to bp_index array
         for ( my $i = 0; $i <= $#$portlist; $i++ ) {
@@ -550,10 +561,10 @@ Max Baker
 
 =head1 SYNOPSIS
 
- my $bridge = new SNMP::Info ( 
+ my $bridge = new SNMP::Info (
                              AutoSpecify => 1,
                              Debug       => 1,
-                             DestHost    => 'switch', 
+                             DestHost    => 'switch',
                              Community   => 'public',
                              Version     => 2
                              );
@@ -574,7 +585,7 @@ Max Baker
     my $port  = $interfaces->{$iid};
 
     print "Port:$port forwarding to $mac\n";
- } 
+ }
 
 =head1 DESCRIPTION
 
@@ -583,12 +594,12 @@ MAC Forwarding Table and Spanning Tree Protocol info.
 
 F<Q-BRIDGE-MIB> holds 802.1q information -- VLANs and Trunking.  Cisco tends
 not to use this MIB, but some proprietary ones.  HP and some nicer vendors use
-this.  This is from C<RFC2674_q>.  
+this.  This is from C<RFC2674_q>.
 
 Create or use a subclass of SNMP::Info that inherits this class.  Do not use
 directly.
 
-For debugging you can call new() directly as you would in SNMP::Info 
+For debugging you can call new() directly as you would in SNMP::Info
 
  my $bridge = new SNMP::Info::Bridge(...);
 
@@ -604,12 +615,11 @@ None.
 
 =item F<Q-BRIDGE-MIB>
 
+=item F<RSTP-MIB>
+
 =back
 
-F<BRIDGE-MIB> needs to be extracted from
-ftp://ftp.cisco.com/pub/mibs/v1/v1.tar.gz
-
-=head1 GLOBAL METHODS
+=head1 GLOBALS
 
 These are methods that return scalar values from SNMP
 
@@ -652,19 +662,19 @@ Returns root of STP.
 
 (C<dot1dStpDesignatedRoot>)
 
-=item $bridge->qb_vlans_max() 
+=item $bridge->qb_vlans_max()
 
 Maximum number of VLANS supported on this device.
 
 (C<dot1qMaxSupportedVlans>)
 
-=item $bridge->qb_vlans() 
+=item $bridge->qb_vlans()
 
 Current number of VLANs that are configured in this device.
 
 (C<dot1qNumVlans>)
 
-=item $bridge->qb_next_vlan_index() 
+=item $bridge->qb_next_vlan_index()
 
 The next available value for C<dot1qVlanIndex> of a local VLAN entry in
 C<dot1qVlanStaticTable>
@@ -696,7 +706,7 @@ IDs.  These are the VLANs which are members of the egress list for the port.
   Example:
   my $interfaces = $bridge->interfaces();
   my $vlans      = $bridge->i_vlan_membership();
-  
+
   foreach my $iid (sort keys %$interfaces) {
     my $port = $interfaces->{$iid};
     my $vlan = join(',', sort(@{$vlans->{$iid}}));
@@ -716,7 +726,7 @@ tagged ports or the VLAN ID.
 
 =item $bridge->qb_fdb_index()
 
-Returns reference to hash: key = VLAN ID, value = FDB ID.
+Returns reference to hash: key = FDB ID, value = VLAN ID.
 
 =item $bridge->v_index()
 
@@ -726,7 +736,7 @@ Returns VLAN IDs
 
 =head2 Forwarding Table (C<dot1dTpFdbEntry>)
 
-=over 
+=over
 
 =item $bridge->fw_mac()
 
@@ -944,7 +954,7 @@ The set of ports which are assigned to the egress list for this VLAN.
 =item $bridge->qb_cv_untagged()
 
 The set of ports which should transmit egress packets for this VLAN as
-untagged. 
+untagged.
 
 (C<dot1qVlanCurrentUntaggedPorts>)
 
@@ -982,7 +992,7 @@ for this VLAN.
 =item $bridge->qb_v_untagged()
 
 The set of ports which should transmit egress packets for this VLAN as
-untagged. 
+untagged.
 
 (C<dot1qVlanStaticUntaggedPorts>)
 
@@ -1022,13 +1032,13 @@ Returns reference to hash of forwarding table entries status
 (C<dot1qTpFdbStatus>)
 
 =back
- 
+
 =head1 SET METHODS
 
 These are methods that provide SNMP set functionality for overridden methods
 or provide a simpler interface to complex set operations.  See
 L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
-operations. 
+operations.
 
 =over
 
