@@ -1,5 +1,4 @@
 # SNMP::Info::EtherLike
-# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,15 +32,16 @@
 package SNMP::Info::EtherLike;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::EtherLike::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::EtherLike::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.31';
+$VERSION = '3.76';
 
 %MIBS = ( 'EtherLike-MIB' => 'etherMIB' );
 
@@ -68,8 +68,7 @@ $VERSION = '3.31';
     'el_xmit_defer'      => 'dot3StatsDeferredTransmissions',
 
     # Ethernet-like Collision Statistics Group
-    'el_coll_count' => 'dot3CollCount',
-    'el_coll_freq'  => 'dot3CollFrequencies'
+    'el_coll_freq'  => 'dot3CollFrequencies',
 );
 
 %MUNGE = ( %SNMP::Info::MUNGE, 'el_duplex' => \&munge_el_duplex, );
@@ -96,22 +95,22 @@ Max Baker
 
 =head1 SYNOPSIS
 
- my $el = new SNMP::Info ( 
+ my $el = new SNMP::Info (
                              AutoSpecify => 1,
                              Debug       => 1,
-                             DestHost    => 'router', 
+                             DestHost    => 'router',
                              Community   => 'public',
                              Version     => 2
                            );
- 
- my $class = $cdp->class();
+
+ my $class = $el->class();
  print " Using device sub class : $class\n";
 
  # Find the duplex setting for a port on a device that implements
  # ETHERLIKE-MIB
  my $interfaces = $el->interfaces();
  my $el_index   = $el->el_index();
- my $el_duplex  = $el->el_duplex(); 
+ my $el_duplex  = $el->el_duplex();
 
  foreach my $el_port (keys %$el_duplex){
     my $duplex = $el_duplex->{$el_port};
@@ -123,7 +122,7 @@ Max Baker
 
 =head1 DESCRIPTION
 
-SNMP::Info::EtherLike is a subclass of SNMP::Info that supplies 
+SNMP::Info::EtherLike is a subclass of SNMP::Info that supplies
 access to the F<ETHERLIKE-MIB> used by some Layer 3 Devices such as
 Cisco routers.
 
@@ -134,7 +133,7 @@ directly.
 
 =head2 Inherited Classes
 
-None.  
+None.
 
 =head2 Required MIBs
 
@@ -144,8 +143,6 @@ None.
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
 =head1 GLOBALS
 
 These are methods that return scalar values from SNMP
