@@ -1,5 +1,4 @@
 # SNMP::Info::Layer1::Asante
-# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,15 +32,16 @@
 package SNMP::Info::Layer1::Asante;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer1;
 
 @SNMP::Info::Layer1::Asante::ISA       = qw/SNMP::Info::Layer1 Exporter/;
 @SNMP::Info::Layer1::Asante::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.28';
+$VERSION = '3.76';
 
 # Set for No CDP
 %GLOBALS = ( %SNMP::Info::Layer1::GLOBALS, );
@@ -81,9 +81,10 @@ sub os_ver {
     my $asante = shift;
     my $descr  = $asante->description();
 
-    if ( $descr =~ /software v(\d+\.\d+)/ ) {
+    if ( defined ($descr) && $descr =~ /software v(\d+\.\d+)/ ) {
         return $1;
     }
+    return;
 }
 
 sub vendor {
@@ -94,7 +95,7 @@ sub model {
     my $asante = shift;
 
     my $id    = $asante->id();
-    my $model = &SNMP::translateObj($id);
+    my $model = SNMP::translateObj($id);
 
     return $model;
 }
@@ -108,8 +109,8 @@ sub i_up {
     my $i_up = {};
     foreach my $port ( keys %$asante_up ) {
         my $up = $asante_up->{$port};
-        $i_up->{$port} = 'down' if $up =~ /on/;
-        $i_up->{$port} = 'up'   if $up =~ /off/;
+        $i_up->{$port} = 'down' if $up =~ /off/;
+        $i_up->{$port} = 'up'   if $up =~ /on/;
     }
 
     return $i_up;
@@ -149,7 +150,7 @@ sub i_name {
     my $asante  = shift;
     my $partial = shift;
 
-    my $i_name = $asante->orig_i_descr($partial) || {};
+    my $i_name = $asante->orig_i_description($partial) || {};
 
     my %i_name;
 
@@ -172,14 +173,14 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $asante = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $asante->class();
@@ -187,7 +188,7 @@ Max Baker
 
 =head1 DESCRIPTION
 
-Provides abstraction to the configuration information obtainable from a 
+Provides abstraction to the configuration information obtainable from an
 Asante device through SNMP.
 
 =head2 Inherited Classes
@@ -226,7 +227,7 @@ Culls software version from description()
 
 =item $asante->vendor()
 
-Returns 'asante' :)
+Returns 'asante'
 
 =item $asante->model()
 
@@ -249,7 +250,7 @@ See L<SNMP::Info::Layer1/"GLOBALS"> for details.
 
 Returns reference to the map between IID and physical Port.
 
-=item $asante->i_description() 
+=item $asante->i_description()
 
 Description of the interface.
 
