@@ -1,5 +1,4 @@
 # SNMP::Info::Layer2::C2900
-# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,15 +32,16 @@
 package SNMP::Info::Layer2::C2900;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer2::Cisco;
 
 @SNMP::Info::Layer2::C2900::ISA = qw/SNMP::Info::Layer2::Cisco Exporter/;
 @SNMP::Info::Layer2::C2900::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.76';
 
 %GLOBALS = (
     %SNMP::Info::Layer2::Cisco::GLOBALS,
@@ -128,25 +128,24 @@ sub i_speed_admin {
     my $c2900   = shift;
     my $partial = shift;
 
-    my %i_speed_admin;
-    my $p_port        = $c2900->p_port() || {};
     my $interfaces    = $c2900->interfaces($partial);
     my $c2900_p_index = $c2900->c2900_p_index() || {};
+    my $c2900_p_admin = $c2900->c2900_p_speed_admin();
 
     my %reverse_2900 = reverse %$c2900_p_index;
-    my $c2900_p_speed
-        = $c2900->c2900_p_speed_admin( $reverse_2900{$partial} );
 
-    my %speeds = (
-        'autoDetect' => 'auto',
-        's10000000'  => '10 Mbps',
-        's100000000' => '100 Mbps',
-    );
-
-    %i_speed_admin
-        = map { $c2900_p_index->{$_} => $speeds{ $c2900_p_speed->{$_} } }
-        keys %$c2900_p_index;
+    my %i_speed_admin;
+    foreach my $if ( keys %$interfaces ) {
+        my $port_2900 = $reverse_2900{$if};
+        next unless defined $port_2900;
+        my $speed = $c2900_p_admin->{$port_2900};
+        next unless defined $speed;
 
+        $speed = 'auto' if $speed eq 'autoDetect';
+        $speed = '10 Mbps' if $speed eq 's10000000';
+        $speed = '100 Mbps' if $speed eq 's100000000';
+        $i_speed_admin{$if} = $speed;
+    }
     return \%i_speed_admin;
 }
 
@@ -190,7 +189,7 @@ sub set_i_duplex_admin {
     return $c2900->set_c2900_p_duplex_admin( $duplexes{$duplex}, $iid );
 }
 
-# Use i_descritption for port key, cuz i_name can be manually entered.
+# Use i_description for port key, cuz i_name can be manually entered.
 sub interfaces {
     my $c2900   = shift;
     my $partial = shift;
@@ -226,7 +225,7 @@ Max Baker
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $c2900 = new SNMP::Info(
                         AutoSpecify => 1,
                         Debug       => 1,
@@ -234,7 +233,7 @@ Max Baker
                         DestHost    => 'myswitch',
                         Community   => 'public',
                         Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $c2900->class();
@@ -242,13 +241,8 @@ Max Baker
 
 =head1 DESCRIPTION
 
-Provides abstraction to the configuration information obtainable from a 
-C2900 device through SNMP. 
-
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above. 
-
- my $c2900 = new SNMP::Info::Layer2::C2900(...);
+Provides abstraction to the configuration information obtainable from a
+C2900 device through SNMP.
 
 =head2 Inherited Classes
 
@@ -282,7 +276,7 @@ These are methods that return scalar value from SNMP
 
 =item $c2900->vendor()
 
-Returns 'cisco' :)
+Returns 'cisco'
 
 =item $c2900->cisco_comm_indexing()
 
@@ -310,8 +304,8 @@ Returns reference to the map between IID and physical Port.
 On the 2900 devices i_name isn't reliable, so we override to just the
 description.
 
-Next all dots are changed for forward slashes so that the physical port name 
-is the same as the broad-casted CDP port name. 
+Next all dots are changed for forward slashes so that the physical port name
+is the same as the broad-casted CDP port name.
     (Ethernet0.1 -> Ethernet0/1)
 
 Also, any weird characters are removed, as I saw a few pop up.
@@ -334,7 +328,7 @@ Returns reference to hash of IIDs to admin speed setting.
 
 =back
 
-=head2 F<C2900-MIB> Port Entry Table 
+=head2 F<C2900-MIB> Port Entry Table
 
 =over
 
@@ -358,7 +352,7 @@ Gives admin setting for Duplex Info
 
 =item $c2900->c2900_p_speed_admin()
 
-Gives Admin speed of port 
+Gives Admin speed of port
 
 (C<c2900PortAdminSpeed>)
 
@@ -373,7 +367,7 @@ See L<SNMP::Info::Layer2::Cisco/"TABLE METHODS"> for details.
 These are methods that provide SNMP set functionality for overridden methods
 or provide a simpler interface to complex set operations.  See
 L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
-operations. 
+operations.
 
 =over
 
@@ -388,7 +382,7 @@ port C<ifIndex>.
 
     Example:
     my %if_map = reverse %{$c2900->interfaces()};
-    $c2900->set_i_speed_admin('auto', $if_map{'FastEthernet0/1'}) 
+    $c2900->set_i_speed_admin('auto', $if_map{'FastEthernet0/1'})
         or die "Couldn't change port speed. ",$c2900->error(1);
 
 =item $c2900->set_i_duplex_admin(duplex, ifIndex)
@@ -402,7 +396,7 @@ port C<ifIndex>.
 
     Example:
     my %if_map = reverse %{$c2900->interfaces()};
-    $c2900->set_i_duplex_admin('auto', $if_map{'FastEthernet0/1'}) 
+    $c2900->set_i_duplex_admin('auto', $if_map{'FastEthernet0/1'})
         or die "Couldn't change port duplex. ",$c2900->error(1);
 
 =back
