@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::Foundry - SNMP Interface to Foundry devices
-# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -33,14 +32,13 @@
 package SNMP::Info::Layer3::Foundry;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 use SNMP::Info::FDP;
-use SNMP::Info::LLDP;
 
 @SNMP::Info::Layer3::Foundry::ISA = qw/
     SNMP::Info::FDP
-    SNMP::Info::LLDP
     SNMP::Info::Layer3
     Exporter
 /;
@@ -48,11 +46,10 @@ use SNMP::Info::LLDP;
 
 our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.76';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     %SNMP::Info::FDP::MIBS,
 
     'FOUNDRY-SN-ROOT-MIB'         => 'foundry',
@@ -60,13 +57,11 @@ $VERSION = '3.68';
     'FOUNDRY-SN-SWITCH-GROUP-MIB' => 'snSwGroupOperMode',
     'FOUNDRY-SN-STACKING-MIB'     => 'snStackingOperUnitRole',
     'FOUNDRY-POE-MIB'             => 'snAgentPoeGblPowerCapacityTotal',
-    'FOUNDRY-SN-SWITCH-GROUP-MIB' => 'snSwGroupOperMode',
     'BROCADE-PRODUCTS-MIB'        => 'brocadeProducts',
 );
 
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     %SNMP::Info::FDP::GLOBALS,
 
     'mac'        => 'ifPhysAddress.1',
@@ -82,7 +77,6 @@ $VERSION = '3.68';
 
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
     %SNMP::Info::FDP::FUNCS,
 
     # FOUNDRY-SN-SWITCH-GROUP-MIB
@@ -120,7 +114,6 @@ $VERSION = '3.68';
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
     %SNMP::Info::FDP::MUNGE,
 
     'ag_mod2_type' => \&SNMP::Info::munge_e_type,
@@ -301,11 +294,74 @@ sub interfaces {
     return $i_descr;
 }
 
+sub set_i_vlan {
+    my ($foundry, $vlan, $iid) = @_;
+    my $i_vlan = $foundry->i_vlan($iid);
+
+    if ( defined $i_vlan ) {
+        print
+            "Changing VLAN from $i_vlan->{$iid} to $vlan on IfIndex: $iid\n"
+            if $foundry->debug();
+
+        # quietly try to remove new vlan association
+        $foundry->set_snVLanByPortMemberRowStatus( 3, "${vlan}.${iid}" );
+        sleep 1;
+        # try to remove old vlan association
+        my $rv_rem = $foundry->set_snVLanByPortMemberRowStatus( 3, "$i_vlan->{$iid}.$iid" );
+        sleep 1;
+
+        unless ($rv_rem) {
+            print "Unable to remove untagged(?) VLAN $i_vlan->{$iid} from IfIndex: $iid\n"
+              if $foundry->debug();
+            #    $foundry->error_throw(
+            #        "Unable to remove VLAN $i_vlan->{$iid} from interface: $iid");
+            #    return;
+        }
+
+        # try to add new one untagged
+        my $rv_add = $foundry->set_multi(
+            ['snVLanByPortMemberRowStatus', "${vlan}.${iid}", 4],
+            ['snVLanByPortMemberTagMode',   "${vlan}.${iid}", 2],
+        );
+        sleep 1;
+
+        unless ($rv_add) {
+            print "Unable to add untagged VLAN $vlan to IfIndex: $iid\n"
+              if $foundry->debug();
+
+            # did not work to add new untagged so add tagged
+            my $rv_add_tagged = $foundry->set_multi([
+              ['snVLanByPortMemberRowStatus', "${vlan}.${iid}", 4],
+              ['snVLanByPortMemberTagMode',   "${vlan}.${iid}", 1],
+            ]);
+            sleep 1;
+
+            if ($rv_add_tagged) {
+                my $rv_change_untagged = $foundry->set_snVLanByPortMemberTagMode( 2, "${vlan}.${iid}" );
+                sleep 1;
+                return $rv_change_untagged if $rv_change_untagged;
+            }
+
+            # try to remove old vlan association
+            # $foundry->set_snVLanByPortMemberRowStatus( 3, "${vlan}.${iid}" );
+
+            # then change to untagged
+            $foundry->error_throw(
+                "Unable to add VLAN $vlan to interface: $iid");
+            return;
+        }
+
+        return $rv_add;
+    }
+    $foundry->error_throw("Can't find ifIndex: $iid - Is it an access port?");
+    return;
+}
+
 # Entity MIB is supported on the Brocade NetIron XMR, NetIron MLX, MLXe,
 # NetIron CES, NetIron CER, and older EdgeIron series devices.
 # Try Entity MIB methods first and fall back to Pseudo ENTITY-MIB methods for
 # other devices.
-# e_fwver, e_hwver, e_swver not supported in psuedo methods, no need to
+# e_fwver, e_hwver, e_swver not supported in pseudo methods, no need to
 # override
 
 sub e_index {
@@ -867,7 +923,7 @@ Max Baker
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
-                          Version     => 1
+                          Version     => 2
                         )
     or die "Can't connect to DestHost.\n";
 
@@ -877,12 +933,8 @@ Max Baker
 
 =head1 DESCRIPTION
 
-Abstraction subclass for Brocade (Foundry) Networks devices.
-
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $foundry = new SNMP::Info::Layer3::Foundry(...);
+Provides abstraction to information obtainable from Brocade (Foundry) Networks
+devices through SNMP. See inherited classes' documentation for inherited methods.
 
 =head2 Inherited Classes
 
@@ -892,14 +944,14 @@ after determining a more specific class using the method above.
 
 =item SNMP::Info::FDP;
 
-=item SNMP::Info::LLDP;
-
 =back
 
 =head2 Required MIBs
 
 =over
 
+=item F<BROCADE-PRODUCTS-MIB>
+
 =item F<FOUNDRY-SN-ROOT-MIB>
 
 =item F<FOUNDRY-SN-AGENT-MIB>
@@ -910,16 +962,12 @@ after determining a more specific class using the method above.
 
 =item F<FOUNDRY-POE-MIB>
 
-=item F<FOUNDRY-SN-SWITCH-GROUP-MIB>
-
 =item Inherited Classes' MIBs
 
 See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
 
 See L<SNMP::Info::FDP/"Required MIBs"> for its own MIB requirements.
 
-See L<SNMP::Info::LLDP/"Required MIBs"> for its own MIB requirements.
-
 =back
 
 =head1 GLOBALS
@@ -1008,10 +1056,6 @@ See documentation in L<SNMP::Info::Layer3/"GLOBALS"> for details.
 
 See documentation in L<SNMP::Info::FDP/"GLOBALS"> for details.
 
-=head2 Global Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
-
 =head1 TABLE METHODS
 
 These are methods that return tables of information in the form of a
@@ -1276,8 +1320,26 @@ See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
 
 See documentation in L<SNMP::Info::FDP/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
+=head1 SET METHODS
 
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
+These are methods that provide SNMP set functionality for overridden methods
+or provide a simpler interface to complex set operations.  See
+L<SNMP::Info/"SETTING DATA VIA SNMP"> for general information on set
+operations.
+
+=over
+
+=item $foundry->set_i_vlan ( vlan, ifIndex )
+
+Changes an access (untagged) port VLAN, must be supplied with the numeric
+VLAN ID and port C<ifIndex>.  This method should only be used on end station
+(non-trunk) ports.
+
+  Example:
+  my %if_map = reverse %{$foundry->interfaces()};
+  $foundry->set_i_vlan('2', $if_map{'FastEthernet0/1'})
+    or die "Couldn't change port VLAN. ",$foundry->error(1);
+
+=back
 
 =cut
