@@ -30,14 +30,13 @@
 package SNMP::Info::Layer3::H3C;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
-use SNMP::Info::LLDP;
 use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
 
 @SNMP::Info::Layer3::H3C::ISA = qw/
   SNMP::Info::IEEE802dot3ad
-  SNMP::Info::LLDP
   SNMP::Info::Layer3
   Exporter
 /;
@@ -45,13 +44,12 @@ use SNMP::Info::IEEE802dot3ad 'agg_ports_lag';
   agg_ports
 /;
 
-use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %MUNGE/;
+our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.76';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     %SNMP::Info::IEEE802dot3ad::MIBS,
     'HH3C-LswDEVM-MIB'     => 'hh3cDevMFanStatus',
     'HH3C-LswINF-MIB'      => 'hh3cSlotPortMax',
@@ -62,7 +60,6 @@ $VERSION = '3.53';
 
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     'fan' => 'hh3cDevMFanStatus.1',
     'ps1_status' => 'hh3cDevMPowerStatus.1',
     'ps2_status' => 'hh3cDevMPowerStatus.2',
@@ -70,26 +67,24 @@ $VERSION = '3.53';
 
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
     %SNMP::Info::IEEE802dot3ad::FUNCS,
     i_duplex_admin => 'hh3cifEthernetDuplex',
 );
 
 %MUNGE = (
     %SNMP::Info::Layer3::MUNGE,
-    %SNMP::Info::LLDP::MUNGE,
     %SNMP::Info::IEEE802dot3ad::MUNGE,
 );
 
 sub vendor {
     my $h3c = shift;
     my $mfg = $h3c->entPhysicalMfgName(1) || {};
-    return $mfg->{1} || "H3C";
+    return $mfg->{1} || "h3c";
 }
 
 sub model {
     my $h3c = shift;
-    
+
     my $descr = $h3c->description();
     if ($descr =~ /^.*\n(.*)\n/) {
         return $1;
@@ -141,6 +136,16 @@ sub i_ignore {
 
 sub agg_ports { return agg_ports_lag(@_) }
 
+# CH: overwrite and always return empty mapping for qb_fdb_index
+# see https://github.com/netdisco/snmp-info/issues/218
+# if no fdb->vlan mapping is available the fdb is assumed to be the vlan
+# which is ok for h3c
+# otherwise h3c will deliver a broken vlan mapping and nodes will jump
+# other all vlans
+sub qb_fdb_index {
+    return {};
+}
+
 1;
 __END__
 
@@ -154,14 +159,14 @@ Jeroen van Ingen
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $h3c = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
                           Version     => 2
-                        ) 
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class      = $h3c->class();
@@ -177,7 +182,7 @@ Subclass for H3C & HP A-series devices
 
 =item SNMP::Info::Layer3
 
-=item SNMP::Info::LLDP
+=item SNMP::Info::IEEE802dot3ad
 
 =back
 
@@ -197,9 +202,9 @@ Subclass for H3C & HP A-series devices
 
 =item Inherited Classes' MIBs
 
-See L<SNMP::Info::Layer3> for its own MIB requirements.
+See L<SNMP::Info::IEEE802dot3ad> for its own MIB requirements.
 
-See L<SNMP::Info::LLDP> for its own MIB requirements.
+See L<SNMP::Info::Layer3> for its own MIB requirements.
 
 =back
 
@@ -223,18 +228,23 @@ Returns the OS extracted from C<sysDescr>.
 
 =item $h3c->os_ver()
 
-Returns the software version. Either C<entPhysicalSoftwareRev.2> or extracted from 
+Returns the software version. Either C<entPhysicalSoftwareRev.2> or extracted from
 C<sysDescr>.
 
+=item $h3c->qb_fdb_index()
+
+overwritten to always return empty hash as implementation on 
+h3c is broken.
+
 =back
 
 =head2 Globals imported from SNMP::Info::Layer3
 
 See documentation in L<SNMP::Info::Layer3> for details.
 
-=head2 Globals imported from SNMP::Info::LLDP
+=head2 Globals imported from SNMP::Info::IEEE802dot3ad
 
-See documentation in L<SNMP::Info::LLDP> for details.
+See documentation in L<SNMP::Info::IEEE802dot3ad> for details.
 
 =head1 TABLE ENTRIES
 
@@ -263,10 +273,6 @@ ifIndex of the corresponding master ports.
 
 See documentation in L<SNMP::Info::Layer3> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP> for details.
-
 =head2 Table Methods imported from SNMP::Info::IEEE802dot3ad
 
 See documentation in L<SNMP::Info::IEEE802dot3ad> for details.
