@@ -1,5 +1,4 @@
 # SNMP::Info::Layer3::HP9300 - SNMP Interface to HP Foundry OEM devices
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,22 +30,21 @@
 package SNMP::Info::Layer3::HP9300;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 use SNMP::Info::FDP;
-use SNMP::Info::LLDP;
 
-@SNMP::Info::Layer3::HP9300::ISA = qw/SNMP::Info::FDP SNMP::Info::LLDP
+@SNMP::Info::Layer3::HP9300::ISA = qw/SNMP::Info::FDP
     SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer3::HP9300::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
+our ($VERSION, %GLOBALS, %FUNCS, %MIBS, %MUNGE);
 
-$VERSION = '3.53';
+$VERSION = '3.76';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
-    %SNMP::Info::LLDP::MIBS,
     %SNMP::Info::FDP::MIBS,
     'HP-SN-ROOT-MIB'         => 'hp',
     'HP-SN-AGENT-MIB'        => 'snChasPwrSupplyDescription',
@@ -55,7 +53,6 @@ $VERSION = '3.53';
 
 %GLOBALS = (
     %SNMP::Info::Layer3::GLOBALS,
-    %SNMP::Info::LLDP::GLOBALS,
     %SNMP::Info::FDP::GLOBALS,
     'mac'        => 'ifPhysAddress.1',
     'chassis'    => 'entPhysicalDescr.1',
@@ -68,7 +65,6 @@ $VERSION = '3.53';
 
 %FUNCS = (
     %SNMP::Info::Layer3::FUNCS,
-    %SNMP::Info::LLDP::FUNCS,
     %SNMP::Info::FDP::FUNCS,
 
     # HP-SN-SWITCH-GROUP-MIB
@@ -82,7 +78,7 @@ $VERSION = '3.53';
 );
 
 %MUNGE = (
-    %SNMP::Info::Layer3::MUNGE, %SNMP::Info::LLDP::MUNGE,
+    %SNMP::Info::Layer3::MUNGE,
     %SNMP::Info::FDP::MUNGE,
 );
 
@@ -209,14 +205,14 @@ Eric Miller
 
 =head1 SYNOPSIS
 
- # Let SNMP::Info determine the correct subclass for you. 
+ # Let SNMP::Info determine the correct subclass for you.
  my $hp9300 = new SNMP::Info(
                           AutoSpecify => 1,
                           Debug       => 1,
                           DestHost    => 'myswitch',
                           Community   => 'public',
-                          Version     => 1
-                        ) 
+                          Version     => 2
+                        )
     or die "Can't connect to DestHost.\n";
 
  my $class = $hp9300->class();
@@ -228,11 +224,6 @@ Eric Miller
 Abstraction subclass for HP network devices which Foundry Networks was the
 Original Equipment Manufacturer (OEM) such as the HP ProCurve 9300 series.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $hp9300 = new SNMP::Info::Layer3::HP9300(...);
-
 =head2 Inherited Classes
 
 =over
@@ -241,8 +232,6 @@ after determining a more specific class using the method above.
 
 =item SNMP::Info::FDP;
 
-=item SNMP::Info::LLDP;
-
 =back
 
 =head2 Required MIBs
@@ -261,8 +250,6 @@ See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
 
 See L<SNMP::Info::FDP/"Required MIBs"> for its own MIB requirements.
 
-See L<SNMP::Info::LLDP/"Required MIBs"> for its own MIB requirements.
-
 =back
 
 =head1 GLOBALS
@@ -286,7 +273,7 @@ Returns 'hp'
 
 =item $hp9300->os_ver()
 
-Returns the software version
+Returns the software version.
 
 =item $hp9300->mac()
 
@@ -338,10 +325,6 @@ See documentation in L<SNMP::Info::Layer3/"GLOBALS"> for details.
 
 See documentation in L<SNMP::Info::FDP/"GLOBALS"> for details.
 
-=head2 Global Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
-
 =head1 TABLE METHODS
 
 These are methods that return tables of information in the form of a reference
@@ -359,11 +342,11 @@ Returns reference to hash of interface names to iids.
 
 Returns reference to hash of interfaces to be ignored.
 
-Ignores interfaces with descriptions of  tunnel,loopback,null 
+Ignores interfaces with descriptions of  tunnel,loopback,null
 
 =item $hp9300->i_duplex()
 
-Returns reference to hash of interface link duplex status. 
+Returns reference to hash of interface link duplex status.
 
 Crosses $hp9300->sw_duplex() with $hp9300->sw_index()
 
@@ -375,13 +358,13 @@ Crosses $hp9300->sw_duplex() with $hp9300->sw_index()
 
 =item $hp9300->sw_index()
 
-Returns reference to hash.  Maps Table to Interface IID. 
+Returns reference to hash.  Maps Table to Interface IID.
 
 (C<snSwPortIfIndex>)
 
 =item $hp9300->sw_duplex()
 
-Returns reference to hash.   Current duplex status for switch ports. 
+Returns reference to hash.   Current duplex status for switch ports.
 
 (C<snSwPortInfoChnMode>)
 
@@ -393,7 +376,7 @@ Returns reference to hash.  Current Port Type .
 
 =item $hp9300->sw_speed()
 
-Returns reference to hash.  Current Port Speed. 
+Returns reference to hash.  Current Port Speed.
 
 (C<snSwPortInfoSpeed>)
 
@@ -407,8 +390,4 @@ See documentation in L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
 
 See documentation in L<SNMP::Info::FDP/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
-
 =cut
