@@ -28,6 +28,7 @@ package SNMP::Info::Layer3::SonicWALL;
 # POSSIBILITY OF SUCH DAMAGE.
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer3;
 
@@ -36,36 +37,40 @@ use SNMP::Info::Layer3;
 
 our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.76';
 
 %MIBS = (
-    %SNMP::Info::Layer2::MIBS, %SNMP::Info::Layer3::MIBS,
+    %SNMP::Info::Layer3::MIBS,
     'SNWL-COMMON-MIB' => 'snwlCommonModule',
 );
 
 %GLOBALS = (
-    %SNMP::Info::Layer2::GLOBALS, %SNMP::Info::Layer3::GLOBALS,
+    %SNMP::Info::Layer3::GLOBALS,
     #From SNWL-COMMON-MIB
-    'sw_model' => 'snwlSysModel',
-    'sw_serial' => 'snwlSysSerialNumber',
+    'sw_model'    => 'snwlSysModel',
+    'sw_serial'   => 'snwlSysSerialNumber',
     'sw_firmware' => 'snwlSysFirmwareVersion',
 );
 
-%FUNCS = ( %SNMP::Info::Layer2::FUNCS, %SNMP::Info::Layer3::FUNCS, );
+%FUNCS = (
+    %SNMP::Info::Layer3::FUNCS,
+);
 
-%MUNGE = ( %SNMP::Info::Layer2::MUNGE, %SNMP::Info::Layer3::MUNGE, );
+%MUNGE = (
+    %SNMP::Info::Layer3::MUNGE,
+);
 
 sub vendor {
-    return 'SonicWALL';
+    return 'sonicwall';
 }
 
 sub os {
         my $sonicos = shift;
         my $swos = $sonicos->sw_firmware();
         if ($swos =~ /Enhanced/) {
-            return 'SonicOS Enhanced';
+            return 'sonicos enhanced';
         }
-        return 'SonicOS Standard';
+        return 'sonicos standard';
 }
 
 sub os_ver {
@@ -107,7 +112,7 @@ phishphreek@gmail.com
                           Debug       => 1,
                           DestHost    => 'myrouter',
                           Community   => 'public',
-                          Version     => 1
+                          Version     => 2
                         )
     or die "Can't connect to DestHost.\n";
 
@@ -116,7 +121,7 @@ phishphreek@gmail.com
 
 =head1 DESCRIPTION
 
-Subclass for Generic SonicWALL Firewalls
+Subclass for SonicWALL Firewalls
 
 =head2 Inherited Classes
 
@@ -130,6 +135,10 @@ Subclass for Generic SonicWALL Firewalls
 
 =over
 
+=item F<SONICWALL-SMI>
+
+=item F<SNWL-COMMON-MIB>
+
 =item Inherited Classes' MIBs
 
 See L<SNMP::Info::Layer3/"Required MIBs"> for its own MIB requirements.
@@ -146,19 +155,19 @@ These are methods that return scalar value from SNMP
 
 =item $router->vendor()
 
-Returns C<'SonicWALL'>
+Returns C<'sonicwall'>
 
 =item $router->os()
 
-Returns C<'SonicOS'>
+Returns C<'sonicos enhanced'> or C<'sonicos standard'> based on C<'snwlSysFirmwareVersion'>
 
 =item $router->os_ver()
 
-Returns '4.2.0.0-10e'
+Returns C<'snwlSysFirmwareVersion'>
 
 =item $router->model()
 
-Returns C<'PRO 3060 Enhanced'>
+Returns C<'snwlSysModel'>
 
 =item $router->serial()
 
