@@ -31,6 +31,7 @@
 package SNMP::Info::Layer7::APC;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::Layer7;
 
@@ -40,7 +41,7 @@ use SNMP::Info::Layer7;
 
 our ($VERSION, %GLOBALS, %MIBS, %FUNCS, %MUNGE);
 
-$VERSION = '3.68';
+$VERSION = '3.76';
 
 %MIBS = (
     %SNMP::Info::Layer7::MIBS,
@@ -133,11 +134,6 @@ Jeroen van Ingen
 Provides abstraction to the configuration information obtainable from a
 APC UPS via SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $apc = new SNMP::Info::Layer7::APC(...);
-
 =head2 Inherited Classes
 
 =over
